@@ -52,7 +52,7 @@ _API_DIGESTS = {
     RawHandler.__call__: {'5ea91e39ab1dc3587a4038805ee90235990b866d'},
 
     # session.py
-    Session.__init__: {'7c25cbd2154cc87e732fe4a343900d7002195973', '8540ad5941a8ad7c88a6f2d7dc446da128be9eaf', '5cd30efc177ceae51ed823224cad711b8c85bcea'},
+    Session.__init__: {'039bdfe7082256a3bffe3492fc6d84f1480fbd6a'},
     Session._register_default_handlers: {'04f247de526b7a0af15737e04019ade52cc65446', '74fa15629c9ea69f79f3a5285357dbf53f734f2d', 'e30e5c3a0f6bc8f002ba679d4bae831914fc67a0'},
     Session.resource: {'5e3568b28281a75eaf9725fab67c33dc16a18144', 'b110781f5a5d148dd1d614e7611650a16cbea372'},
 
